@@ -11,45 +11,33 @@
 #*# See demo/demo03sonar_B.r for a somewhat longer tuning run, with two tuners SPOT and LHD.
 
 ## load package and set working directory (dir with .apd, .conf and main_*.r file)
-#library(TDMR);
 path <- paste(find.package("TDMR"), "demo02sonar",sep="/");
 #path <- paste("../inst", "demo02sonar",sep="/");
-oldwd <- getwd();  setwd(path);
-source("main_sonar.r");    # from working dir
 
 ## preliminary settings for TDMR
-tdm <- list( mainFunc="main_sonar"
-            , runList = "sonar_04.conf"
-            , umode=c("CV")           # ["CV" | "RSUB" | "TST" | "SP_T" ]
-            , tuneMethod = c("lhd")   # c("spot","lhd")
-            , filenameEnvT="demo03.RData"   # file to save environment envT (in working dir)
-            , nrun=1, nfold=2         # repeats and CV-folds for the unbiased runs
+tdm <- list( mainFile="main_sonar.r"
+            , runList = c("sonar_04.conf","sonar_06.conf")
+            , umode="CV"              # { "CV" | "RSUB" | "TST" | "SP_T" }
+            , tuneMethod = c("lhd")
+            , filenameEnvT="demo03.RData"   # file to save environment envT (in dir 'path')
+            , nrun=3, nfold=2         # repeats and CV-folds for the unbiased runs
             , nExperim=1
             , parallelCPUs=1
             , parallelFuncs=c("readCmdSonar")
-            , optsVerbosity = 0       # the verbosity for the unbiased runs
+            , optsVerbosity = 3       # the verbosity for the unbiased runs
             );
-## tdm$runList="sonar_04.conf" has the settings for the tuning process (e.g. 
+## Each element of tdm$runList has the settings for one tuning process (e.g. 
 ##    - auto.loop.steps = number of SPOT generations       
 ##    - auto.loop.evals = budget of model building runs and 
 ##    - io.roiFileName = "sonar_04.roi"
-## ). tdm$runList could contain other files as well (e.g. 
-##    c("sonar_01.conf","sonar_02.conf","sonar_03.conf")
-## ), if desired.
+## ). 
 
 spotStep = "auto";    ## spotStep can be either "auto" (do automatic tuning) or 
                       ## "rep" (make a visual report and an unbiased run on best results)
-
-## construct an initial environment envT from tdm
-## (this contains also tdmDefaultsFill(tdm))
-## then run tdmBigLoop
-envT <- tdmExecSpotStep(tdm,spotStep);
-## see demo03sonar_A.r for an identical version where the contents of tdmExecSpotStep 
-## is explicitly shown
-
-setwd(oldwd);               # restore old working directory
-
-## the resulting tuning surface(s) (the metamodel(s)) can be inspected interactively with
-##      load(paste(path,tdm$filenameEnvT,sep="/"));     
+source(paste(path,tdm$mainFile,sep="/"));    
+source(paste(path,"start_bigLoop.r",sep="/"),chdir=TRUE);    # change dir to 'path' while sourcing
+              
+## the resulting tuning surface (the metamodel) can be inspected interactively with
+##      envT <- tdmEnvTLoad(paste(path,tdm$filenameEnvT,sep="/"));     
 ##      tdmPlotResMeta(envT);
-## (load(...) is only needed for reloading envT in another R-session)
+## (tdmEnvTLoad(...) is only needed for reloading envT in another R-session)
